@@ -42,6 +42,8 @@
 #'   arguments to internal [logspline::logspline()].)
 #' @inheritParams hdi
 #'
+#' @inheritSection hdi Model components
+#'
 #' @return A data frame containing the (log) Bayes factor representing evidence
 #'   *against* the null  (Use `as.numeric()` to extract the non-log Bayes
 #'   factors; see examples).
@@ -85,21 +87,22 @@
 #' (Note that by default, `brms::brm()` uses flat priors for fixed-effects;
 #' See example below.)
 #' \cr\cr
-#' It is important to provide the correct `prior` for meaningful results.
-#' \itemize{
-#'   \item When `posterior` is a numerical vector, `prior` should also be a numerical vector.
-#'   \item When `posterior` is a `data.frame`, `prior` should also be a `data.frame`, with matching column order.
-#'   \item When `posterior` is a `stanreg`, `brmsfit` or other supported Bayesian model: \itemize{
-#'     \item `prior` can be set to `NULL`, in which case prior samples are drawn internally.
-#'     \item `prior` can also be a model equivalent to `posterior` but with samples from the priors *only*. See [unupdate()].
-#'     \item **Note:** When `posterior` is a `brmsfit_multiple` model, `prior` **must** be provided.
-#'   }
-#'   \item When `posterior` is an `emmGrid` / `emm_list` object: \itemize{
-#'     \item `prior` should also be an `emmGrid` / `emm_list` object equivalent to `posterior` but created with a model of priors samples *only*. See [unupdate()].
-#'     \item `prior` can also be the original (posterior) *model*. If so, the function will try to update the `emmGrid` / `emm_list` to use the [unupdate()]d prior-model. (*This cannot be done for `brmsfit` models.*)
-#'     \item **Note**: When the `emmGrid` has undergone any transformations (`"log"`, `"response"`, etc.), or `regrid`ing, then `prior` must be an `emmGrid` object, as stated above.
-#'   }
-#' }
+#' It is important to provide the correct `prior` for meaningful results,
+#' to match the `posterior`-type input:
+#'
+#' - **A numeric vector** - `prior` should also be a _numeric vector_, representing the prior-estimate.
+#' - **A data frame** - `prior` should also be a _data frame_, representing the prior-estimates, in matching column order.
+#'   - If `rvar_col` is specified, `prior` should be _the name of an `rvar` column_ that represents the prior-estimates.
+#' - **Supported Bayesian model (`stanreg`, `brmsfit`, etc.)**
+#'   - `prior` should be _a model an equivalent model with MCMC samples from the priors **only**_. See [unupdate()].
+#'   - If `prior` is set to `NULL`, [unupdate()] is called internally (not supported for `brmsfit_multiple` model).
+#' - **Output from a `{marginaleffects}` function** - `prior` should also be _an equivalent output_ from a `{marginaleffects}` function based on a prior-model
+#'  (See [unupdate()]).
+#' - **Output from an `{emmeans}` function**
+#'   - `prior` should also be _an equivalent output_ from an `{emmeans}` function based on a prior-model (See [unupdate()]).
+#'   - `prior` can also be _the original (posterior) model_, in which case the function
+#'      will try to "unupdate" the estimates (not supported if the estimates have undergone
+#'      any transformations -- `"log"`, `"response"`, etc. -- or any `regrid`ing).
 #'
 #' @section Interpreting Bayes Factors:
 #' A Bayes factor greater than 1 can be interpreted as evidence against the
@@ -108,70 +111,78 @@
 #' Bayes factor smaller than 1/3 indicates substantial evidence in favor of the
 #' null-model) (\cite{Wetzels et al. 2011}).
 #'
-#' @examples
+#' @examplesIf require("logspline")
 #' library(bayestestR)
-#' if (require("logspline")) {
-#'   prior <- distribution_normal(1000, mean = 0, sd = 1)
-#'   posterior <- distribution_normal(1000, mean = .5, sd = .3)
-#'   (BF_pars <- bayesfactor_parameters(posterior, prior))
+#' prior <- distribution_normal(1000, mean = 0, sd = 1)
+#' posterior <- distribution_normal(1000, mean = .5, sd = .3)
+#' (BF_pars <- bayesfactor_parameters(posterior, prior, verbose = FALSE))
 #'
-#'   as.numeric(BF_pars)
-#' }
-#' \dontrun{
+#' as.numeric(BF_pars)
+#'
+#' @examplesIf require("rstanarm") && require("emmeans") && require("logspline")
+#' \donttest{
 #' # rstanarm models
 #' # ---------------
-#' if (require("rstanarm") && require("emmeans") && require("logspline")) {
-#'   contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
-#'   stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep)
-#'   bayesfactor_parameters(stan_model)
-#'   bayesfactor_parameters(stan_model, null = rope_range(stan_model))
+#' contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
+#' stan_model <- suppressWarnings(stan_lmer(
+#'   extra ~ group + (1 | ID),
+#'   data = sleep,
+#'   refresh = 0
+#' ))
+#' bayesfactor_parameters(stan_model, verbose = FALSE)
+#' bayesfactor_parameters(stan_model, null = rope_range(stan_model))
 #'
-#'   # emmGrid objects
-#'   # ---------------
-#'   group_diff <- pairs(emmeans(stan_model, ~group))
-#'   bayesfactor_parameters(group_diff, prior = stan_model)
+#' # emmGrid objects
+#' # ---------------
+#' group_diff <- pairs(emmeans(stan_model, ~group, data = sleep))
+#' bayesfactor_parameters(group_diff, prior = stan_model, verbose = FALSE)
 #'
-#'   # Or
-#'   group_diff_prior <- pairs(emmeans(unupdate(stan_model), ~group))
-#'   bayesfactor_parameters(group_diff, prior = group_diff_prior)
+#' # Or
+#' # group_diff_prior <- pairs(emmeans(unupdate(stan_model), ~group))
+#' # bayesfactor_parameters(group_diff, prior = group_diff_prior, verbose = FALSE)
 #' }
-#'
+#' @examplesIf require("brms") && require("logspline")
 #' # brms models
 #' # -----------
-#' if (require("brms")) {
-#'   contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
-#'   my_custom_priors <-
-#'     set_prior("student_t(3, 0, 1)", class = "b") +
-#'     set_prior("student_t(3, 0, 1)", class = "sd", group = "ID")
+#' \dontrun{
+#' contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
+#' my_custom_priors <-
+#'   set_prior("student_t(3, 0, 1)", class = "b") +
+#'   set_prior("student_t(3, 0, 1)", class = "sd", group = "ID")
 #'
-#'   brms_model <- brm(extra ~ group + (1 | ID),
-#'     data = sleep,
-#'     prior = my_custom_priors
-#'   )
-#'   bayesfactor_parameters(brms_model)
-#' }
+#' brms_model <- suppressWarnings(brm(extra ~ group + (1 | ID),
+#'   data = sleep,
+#'   prior = my_custom_priors,
+#'   refresh = 0
+#' ))
+#' bayesfactor_parameters(brms_model, verbose = FALSE)
 #' }
+#'
 #' @references
-#' \itemize{
-#' \item Wagenmakers, E. J., Lodewyckx, T., Kuriyal, H., and Grasman, R. (2010).
+#'
+#' - Wagenmakers, E. J., Lodewyckx, T., Kuriyal, H., and Grasman, R. (2010).
 #' Bayesian hypothesis testing for psychologists: A tutorial on the
 #' Savage-Dickey method. Cognitive psychology, 60(3), 158-189.
-#' \item Heck, D. W. (2019). A caveat on the Savage–Dickey density ratio: The
+#'
+#' - Heck, D. W. (2019). A caveat on the Savage–Dickey density ratio: The
 #' case of computing Bayes factors for regression parameters. British Journal of
 #' Mathematical and Statistical Psychology, 72(2), 316-333.
-#' \item Morey, R. D., & Wagenmakers, E. J. (2014). Simple relation between
+#'
+#' - Morey, R. D., & Wagenmakers, E. J. (2014). Simple relation between
 #' Bayesian order-restricted and point-null hypothesis tests. Statistics &
 #' Probability Letters, 92, 121-124.
-#' \item Morey, R. D., & Rouder, J. N. (2011). Bayes factor approaches for
+#'
+#' - Morey, R. D., & Rouder, J. N. (2011). Bayes factor approaches for
 #' testing interval null hypotheses. Psychological methods, 16(4), 406.
-#' \item Liao, J. G., Midya, V., & Berg, A. (2020). Connecting and contrasting
+#'
+#' - Liao, J. G., Midya, V., & Berg, A. (2020). Connecting and contrasting
 #' the Bayes factor and a modified ROPE procedure for testing interval null
 #' hypotheses. The American Statistician, 1-19.
-#' \item Wetzels, R., Matzke, D., Lee, M. D., Rouder, J. N., Iverson, G. J., and
+#'
+#' - Wetzels, R., Matzke, D., Lee, M. D., Rouder, J. N., Iverson, G. J., and
 #' Wagenmakers, E.-J. (2011). Statistical Evidence in Experimental Psychology:
 #' An Empirical Comparison Using 855 t Tests. Perspectives on Psychological
 #' Science, 6(3), 291–298. \doi{10.1177/1745691611406923}
-#' }
 #'
 #' @author Mattan S. Ben-Shachar
 #'
@@ -180,8 +191,8 @@ bayesfactor_parameters <- function(posterior,
                                    prior = NULL,
                                    direction = "two-sided",
                                    null = 0,
-                                   verbose = TRUE,
-                                   ...) {
+                                   ...,
+                                   verbose = TRUE) {
   UseMethod("bayesfactor_parameters")
 }
 
@@ -191,10 +202,10 @@ bayesfactor_pointnull <- function(posterior,
                                   prior = NULL,
                                   direction = "two-sided",
                                   null = 0,
-                                  verbose = TRUE,
-                                  ...) {
-  if (length(null) > 1) {
-    message("'null' is a range - computing a ROPE based Bayes factor.")
+                                  ...,
+                                  verbose = TRUE) {
+  if (length(null) > 1L && verbose) {
+    insight::format_alert("`null` is a range - computing a ROPE based Bayes factor.")
   }
 
   bayesfactor_parameters(
@@ -212,11 +223,11 @@ bayesfactor_pointnull <- function(posterior,
 bayesfactor_rope <- function(posterior,
                              prior = NULL,
                              direction = "two-sided",
-                             null = rope_range(posterior),
-                             verbose = TRUE,
-                             ...) {
-  if (length(null) < 2) {
-    message("'null' is a point - computing a Savage-Dickey (point null) Bayes factor.")
+                             null = rope_range(posterior, verbose = FALSE),
+                             ...,
+                             verbose = TRUE) {
+  if (length(null) < 2 && verbose) {
+    insight::format_alert("'null' is a point - computing a Savage-Dickey (point null) Bayes factor.")
   }
 
   bayesfactor_parameters(
@@ -243,16 +254,19 @@ bf_rope <- bayesfactor_rope
 
 #' @rdname bayesfactor_parameters
 #' @export
-bayesfactor_parameters.numeric <- function(posterior, prior = NULL, direction = "two-sided", null = 0, verbose = TRUE, ...) {
+bayesfactor_parameters.numeric <- function(posterior,
+                                           prior = NULL,
+                                           direction = "two-sided",
+                                           null = 0,
+                                           ...,
+                                           verbose = TRUE) {
   # nm <- insight::safe_deparse(substitute(posterior)
 
   if (is.null(prior)) {
     prior <- posterior
     if (verbose) {
-      warning(
-        "Prior not specified! ",
-        "Please specify a prior (in the form 'prior = distribution_normal(1000, 0, 1)')",
-        " to get meaningful results."
+      insight::format_warning(
+        "Prior not specified! Please specify a prior (in the form 'prior = distribution_normal(1000, 0, 1)') to get meaningful results."
       )
     }
   }
@@ -277,19 +291,16 @@ bayesfactor_parameters.stanreg <- function(posterior,
                                            prior = NULL,
                                            direction = "two-sided",
                                            null = 0,
-                                           verbose = TRUE,
-                                           effects = c("fixed", "random", "all"),
-                                           component = c("conditional", "location", "smooth_terms", "sigma", "zi", "zero_inflated", "all"),
+                                           effects = "fixed",
+                                           component = "conditional",
                                            parameters = NULL,
-                                           ...) {
-  cleaned_parameters <- insight::clean_parameters(posterior)
-  effects <- match.arg(effects)
-  component <- match.arg(component)
+                                           ...,
+                                           verbose = TRUE) {
+  cleaned_parameters <- .get_cleaned_parameters(posterior, ...)
 
   samps <- .clean_priors_and_posteriors(posterior, prior,
-    verbose = verbose,
     effects = effects, component = component,
-    parameters = parameters
+    parameters = parameters, verbose = verbose
   )
 
   # Get BFs
@@ -303,7 +314,8 @@ bayesfactor_parameters.stanreg <- function(posterior,
 
   class(bf_val) <- class(temp)
   attr(bf_val, "clean_parameters") <- cleaned_parameters
-  attr(bf_val, "hypothesis") <- attr(temp, "hypothesis") # don't change the name of this attribute - it is used only internally for "see" and printing
+  # don't change the name of this attribute - it is used only internally for "see" and printing
+  attr(bf_val, "hypothesis") <- attr(temp, "hypothesis")
   attr(bf_val, "direction") <- attr(temp, "direction")
   attr(bf_val, "plot_data") <- attr(temp, "plot_data")
 
@@ -311,20 +323,17 @@ bayesfactor_parameters.stanreg <- function(posterior,
 }
 
 
-
-#' @rdname bayesfactor_parameters
 #' @export
 bayesfactor_parameters.brmsfit <- bayesfactor_parameters.stanreg
 
 
-#' @rdname bayesfactor_parameters
 #' @export
 bayesfactor_parameters.blavaan <- function(posterior,
                                            prior = NULL,
                                            direction = "two-sided",
                                            null = 0,
-                                           verbose = TRUE,
-                                           ...) {
+                                           ...,
+                                           verbose = TRUE) {
   cleaned_parameters <- insight::clean_parameters(posterior)
 
   samps <- .clean_priors_and_posteriors(posterior, prior,
@@ -342,7 +351,8 @@ bayesfactor_parameters.blavaan <- function(posterior,
 
   class(bf_val) <- class(temp)
   attr(bf_val, "clean_parameters") <- cleaned_parameters
-  attr(bf_val, "hypothesis") <- attr(temp, "hypothesis") # don't change the name of this attribute - it is used only internally for "see" and printing
+  # don't change the name of this attribute - it is used only internally for "see" and printing
+  attr(bf_val, "hypothesis") <- attr(temp, "hypothesis")
   attr(bf_val, "direction") <- attr(temp, "direction")
   attr(bf_val, "plot_data") <- attr(temp, "plot_data")
 
@@ -355,56 +365,90 @@ bayesfactor_parameters.emmGrid <- function(posterior,
                                            prior = NULL,
                                            direction = "two-sided",
                                            null = 0,
-                                           verbose = TRUE,
-                                           ...) {
-  samps <- .clean_priors_and_posteriors(posterior, prior,
+                                           ...,
+                                           verbose = TRUE) {
+  samps <- .clean_priors_and_posteriors(
+    posterior,
+    prior,
     verbose = verbose
   )
 
   # Get BFs
-  bayesfactor_parameters.data.frame(
-    posterior = samps$posterior, prior = samps$prior,
-    direction = direction, null = null,
-    verbose = verbose, ...
+  out <- bayesfactor_parameters.data.frame(
+    posterior = samps$posterior,
+    prior = samps$prior,
+    direction = direction,
+    null = null,
+    verbose = verbose,
+    ...
   )
+  .append_datagrid(out, posterior)
 }
 
 #' @export
 bayesfactor_parameters.emm_list <- bayesfactor_parameters.emmGrid
 
+#' @export
+bayesfactor_parameters.slopes <- bayesfactor_parameters.emmGrid
+
+#' @export
+bayesfactor_parameters.predictions <- bayesfactor_parameters.emmGrid
+
+#' @export
+bayesfactor_parameters.comparisons <- bayesfactor_parameters.emmGrid
+
 
 #' @rdname bayesfactor_parameters
+#' @inheritParams p_direction
 #' @export
 bayesfactor_parameters.data.frame <- function(posterior,
                                               prior = NULL,
                                               direction = "two-sided",
                                               null = 0,
-                                              verbose = TRUE,
-                                              ...) {
+                                              rvar_col = NULL,
+                                              ...,
+                                              verbose = TRUE) {
+  x_rvar <- .possibly_extract_rvar_col(posterior, rvar_col)
+  if (length(x_rvar) > 0L) {
+    cl <- match.call()
+    cl[[1]] <- bayestestR::bayesfactor_parameters
+    cl$posterior <- x_rvar
+    cl$rvar_col <- NULL
+    prior_rvar <- .possibly_extract_rvar_col(posterior, prior)
+    if (length(prior_rvar) > 0L) {
+      cl$prior <- prior_rvar
+    }
+    out <- eval.parent(cl)
+
+    obj_name <- insight::safe_deparse_symbol(substitute(posterior))
+    attr(out, "object_name") <- sprintf('%s[["%s"]]', obj_name, rvar_col)
+
+    return(.append_datagrid(out, posterior))
+  }
+
   # find direction
   direction <- .get_direction(direction)
 
   if (is.null(prior)) {
     prior <- posterior
-    warning(
-      "Prior not specified! ",
-      "Please specify priors (with column order matching 'posterior')",
-      " to get meaningful results."
-    )
+    if (verbose) {
+      insight::format_warning(
+        "Prior not specified! Please specify priors (with column order matching 'posterior') to get meaningful results."
+      )
+    }
   }
 
   if (verbose && length(null) == 1L && (nrow(posterior) < 4e4 || nrow(prior) < 4e4)) {
-    warning(
-      "Bayes factors might not be precise.\n",
-      "For precise Bayes factors, sampling at least 40,000 posterior samples is recommended.",
-      call. = FALSE
+    insight::format_warning(
+      "Bayes factors might not be precise.",
+      "For precise Bayes factors, sampling at least 40,000 posterior samples is recommended."
     )
   }
 
 
-  sdbf <- numeric(ncol(posterior))
+  sdlogbf <- numeric(ncol(posterior))
   for (par in seq_along(posterior)) {
-    sdbf[par] <- .bayesfactor_parameters(
+    sdlogbf[par] <- .logbayesfactor_parameters(
       posterior[[par]],
       prior[[par]],
       direction = direction,
@@ -415,7 +459,7 @@ bayesfactor_parameters.data.frame <- function(posterior,
 
   bf_val <- data.frame(
     Parameter = colnames(posterior),
-    log_BF = log(sdbf),
+    log_BF = sdlogbf,
     stringsAsFactors = FALSE
   )
 
@@ -438,11 +482,11 @@ bayesfactor_parameters.draws <- function(posterior,
                                          prior = NULL,
                                          direction = "two-sided",
                                          null = 0,
-                                         verbose = TRUE,
-                                         ...) {
+                                         ...,
+                                         verbose = TRUE) {
   bayesfactor_parameters(
     .posterior_draws_to_df(posterior),
-    prior = prior,
+    prior = if (!is.null(prior)) .posterior_draws_to_df(prior),
     direction = direction,
     null = null,
     verbose = verbose,
@@ -455,23 +499,23 @@ bayesfactor_parameters.rvar <- bayesfactor_parameters.draws
 
 
 #' @keywords internal
-.bayesfactor_parameters <- function(posterior,
-                                    prior,
-                                    direction = 0,
-                                    null = 0,
-                                    ...) {
+.logbayesfactor_parameters <- function(posterior,
+                                       prior,
+                                       direction = 0,
+                                       null = 0,
+                                       ...) {
   stopifnot(length(null) %in% c(1, 2))
 
   if (isTRUE(all.equal(posterior, prior))) {
-    return(1)
+    return(0)
   }
 
   insight::check_if_installed("logspline")
 
   if (length(null) == 1) {
-    relative_density <- function(samples) {
+    relative_loglikelihood <- function(samples) {
       f_samples <- .logspline(samples, ...)
-      d_samples <- logspline::dlogspline(null, f_samples)
+      d_samples <- logspline::dlogspline(null, f_samples, log = TRUE)
 
       if (direction < 0) {
         norm_samples <- logspline::plogspline(null, f_samples)
@@ -481,54 +525,46 @@ bayesfactor_parameters.rvar <- bayesfactor_parameters.draws
         norm_samples <- 1
       }
 
-      d_samples / norm_samples
+      d_samples - log(norm_samples)
     }
-
-    return(relative_density(prior) /
-      relative_density(posterior))
   } else if (length(null) == 2) {
     null <- sort(null)
     null[is.infinite(null)] <- 1.797693e+308 * sign(null[is.infinite(null)])
 
-    f_prior <- .logspline(prior, ...)
-    f_posterior <- .logspline(posterior, ...)
+    relative_loglikelihood <- function(samples) {
+      f_samples <- .logspline(samples, ...)
+      p_samples <- diff(logspline::plogspline(null, f_samples))
 
-    h0_prior <- diff(logspline::plogspline(null, f_prior))
-    h0_post <- diff(logspline::plogspline(null, f_posterior))
+      if (direction < 0) {
+        norm_samples <- logspline::plogspline(min(null), f_samples)
+      } else if (direction > 0) {
+        norm_samples <- 1 - logspline::plogspline(max(null), f_samples)
+      } else {
+        norm_samples <- 1 - p_samples
+      }
 
-    BF_null_full <- h0_post / h0_prior
-
-    if (direction < 0) {
-      h1_prior <- logspline::plogspline(min(null), f_prior)
-      h1_post <- logspline::plogspline(min(null), f_posterior)
-    } else if (direction > 0) {
-      h1_prior <- 1 - logspline::plogspline(max(null), f_prior)
-      h1_post <- 1 - logspline::plogspline(max(null), f_posterior)
-    } else {
-      h1_prior <- 1 - h0_prior
-      h1_post <- 1 - h0_post
+      log(p_samples) - log(norm_samples)
     }
-    BF_alt_full <- h1_post / h1_prior
-
-    return(BF_alt_full / BF_null_full)
   }
+
+  relative_loglikelihood(prior) - relative_loglikelihood(posterior)
 }
 
 # Bad Methods -------------------------------------------------------------
 
 #' @export
 bayesfactor_parameters.bayesfactor_models <- function(...) {
-  stop(
-    "Oh no, 'bayesfactor_parameters()' does not know how to deal with multiple models :(\n",
+  insight::format_error(
+    "Oh no, 'bayesfactor_parameters()' does not know how to deal with multiple models :(",
     "You might want to use 'bayesfactor_inclusion()' here to test specific terms across models."
   )
 }
 
 #' @export
 bayesfactor_parameters.sim <- function(...) {
-  stop(
-    "Bayes factors are based on the shift from a prior to a posterior. ",
-    "Since simulated draws are not based on any priors, computing Bayes factors does not make sense :(\n",
+  insight::format_error(
+    "Bayes factors are based on the shift from a prior to a posterior.",
+    "Since simulated draws are not based on any priors, computing Bayes factors does not make sense :(",
     "You might want to try `rope`, `ci`, `pd` or `pmap` for posterior-based inference."
   )
 }
