@@ -4,17 +4,15 @@
 #' and statistics, in which a trend appears in several different groups of data
 #' but disappears or reverses when these groups are combined.
 #'
-#' @param n The number of observations for each group to be generated (minimum
-#'   4).
-#' @param groups Number of groups (groups can be participants, clusters,
-#'   anything).
+#' @param n The number of observations for each group to be generated (minimum 4).
+#' @param groups Number of groups (groups can be participants, clusters, anything).
 #' @param difference Difference between groups.
 #' @param group_prefix The prefix of the group name (e.g., "G_1", "G_2", "G_3", ...).
 #' @inheritParams simulate_correlation
 #'
 #' @return A dataset.
 #'
-#' @examples
+#' @examplesIf requireNamespace("MASS", quietly = TRUE)
 #' data <- simulate_simpson(n = 10, groups = 5, r = 0.5)
 #'
 #' if (require("ggplot2")) {
@@ -30,17 +28,17 @@ simulate_simpson <- function(n = 100,
                              difference = 1,
                              group_prefix = "G_") {
   if (n <= 3) {
-    stop("The number of observation `n` should be higher than 3", call. = FALSE)
+    insight::format_error("The number of observations `n` should be larger than 3.")
   }
 
-  data <- data.frame()
+  out <- data.frame()
   for (i in 1:groups) {
     dat <- simulate_correlation(n = n, r = r)
     dat$V1 <- dat$V1 + difference * i # (i * -sign(r))
     dat$V2 <- dat$V2 + difference * (i * -sign(r))
     dat$Group <- sprintf(paste0(group_prefix, "%0", nchar(trunc(abs(groups))), "d"), i)
-    data <- rbind(data, dat)
+    out <- rbind(out, dat)
   }
 
-  data
+  out
 }
