@@ -3,18 +3,21 @@
   tryCatch(code, error = function(e) on_error)
 }
 
+
 # select rows where values in "variable" match "value"
 #' @keywords internal
 .select_rows <- function(data, variable, value) {
   data[which(data[[variable]] == value), ]
 }
 
+
 #' select numerics columns
 #' @keywords internal
 .select_nums <- function(x) {
   x[unlist(lapply(x, is.numeric))]
 }
 
+
 #' @keywords internal
 .retrieve_model <- function(x) {
   # retrieve model
@@ -38,6 +41,7 @@
   model
 }
 
+
 #' @keywords internal
 .dynGet <- function(x,
                     ifnotfound = stop(gettextf("%s not found", sQuote(x)), domain = NA, call. = FALSE),
@@ -57,6 +61,7 @@
   ifnotfound
 }
 
+
 #' @keywords internal
 .get_direction <- function(direction) {
   if (length(direction) > 1) {
@@ -93,7 +98,30 @@
 }
 
 
+#' Prepare output data frame for printing
+#'
+#' @description
+#' This is an internal helper function to standardize and enrich the output of
+#' various `bayestestR` functions (like `ci()`, `hdi()`, `rope()`, etc.).
+#' Its main purpose is to merge a data frame containing analysis results
+#' (e.g., credible intervals) with a data frame of "cleaned" parameter
+#' information (from `insight::clean_parameters()`).
+#'
+#' This process adds human-readable parameter names and model component
+#' information (like fixed or random effects) to the output. It also includes
+#' special handling for complex models, such as multivariate models from
+#' `rstanarm` or `brms`, where response variables need to be parsed from
+#' parameter names.
+#'
+#' @param temp A data frame with estimation results, like CIs or point estimates.
+#' @param cleaned_parameters A data frame as returned by
+#'   `insight::clean_parameters()`.
+#' @param is_stan_mv Logical, indicates if the model is a `stanmvreg` object.
+#' @param is_brms_mv Logical, indicates if the model is a `brms` multivariate
+#'   model.
+#'
 #' @keywords internal
+#' @noRd
 .prepare_output <- function(temp,
                             cleaned_parameters,
                             is_stan_mv = FALSE,
@@ -172,39 +200,12 @@
   }
 }
 
-#' @keywords internal
-.is_baysian_grid <- function(x) {
-  UseMethod(".is_baysian_grid")
-}
-
-#' @keywords internal
-.is_baysian_grid.emmGrid <- function(x) {
-  if (inherits(x, "emm_list")) {
-    x <- x[[1]]
-  }
-  post.beta <- methods::slot(x, "post.beta")
-  !(all(dim(post.beta) == 1) && is.na(post.beta))
-}
-
-#' @keywords internal
-.is_baysian_grid.emm_list <- .is_baysian_grid.emmGrid
-
-#' @keywords internal
-.is_baysian_grid.slopes <- function(x) {
-  !is.null(attr(x, "posterior_draws"))
-}
-
-#' @keywords internal
-.is_baysian_grid.predictions <- .is_baysian_grid.slopes
-
-#' @keywords internal
-.is_baysian_grid.comparisons <- .is_baysian_grid.slopes
 
 # safe add cleaned parameter names to a model object
-.add_clean_parameters_attribute <- function(params, model) {
+.add_clean_parameters_attribute <- function(params, model, ...) {
   cp <- tryCatch(
     {
-      insight::clean_parameters(model)
+      .get_cleaned_parameters(model, ...)
     },
     error = function(e) {
       NULL
@@ -214,88 +215,15 @@
   params
 }
 
-#' @keywords internal
-.append_datagrid <- function(results, object, long = FALSE) {
-  UseMethod(".append_datagrid", object = object)
-}
-
-#' @keywords internal
-.append_datagrid.emmGrid <- function(results, object, long = FALSE) {
-  # results is assumed to be a data frame with "Parameter" column
-  # object is an emmeans / marginalefeects that results is based on
-
-  all_attrs <- attributes(results) # save attributes for later
-  all_class <- class(results)
-
-  datagrid <- insight::get_datagrid(object)
-  grid_names <- colnames(datagrid)
-
-  if (long || nrow(datagrid) < nrow(results)) {
-    datagrid$Parameter <- unique(results$Parameter)
-    results <- datawizard::data_merge(datagrid, results, by = "Parameter")
-    results$Parameter <- NULL
-    class(results) <- all_class
-  } else {
-    results[colnames(datagrid)] <- datagrid
-    results$Parameter <- NULL
-    results <- results[, c(grid_names, setdiff(colnames(results), grid_names)), drop = FALSE]
-
-    # add back attributes
-    most_attrs <- all_attrs[setdiff(names(all_attrs), names(attributes(datagrid)))]
-    attributes(results)[names(most_attrs)] <- most_attrs
-  }
-
-
-  attr(results, "idvars") <- grid_names
-  results
-}
-
-.append_datagrid.emm_list <- .append_datagrid.emmGrid
-
-.append_datagrid.slopes <- .append_datagrid.emmGrid
-
-.append_datagrid.predictions <- .append_datagrid.emmGrid
-
-.append_datagrid.comparisons <- .append_datagrid.emmGrid
-
-.append_datagrid.data.frame <- function(results, object, long = FALSE) {
-  # results is assumed to be a data frame with "Parameter" column
-  # object is a data frame with an rvar column that results is based on
-
-  all_attrs <- attributes(results) # save attributes for later
-  all_class <- class(results)
-
-  is_rvar <- vapply(object, inherits, FUN.VALUE = logical(1), "rvar")
-  grid_names <- colnames(object)[!is_rvar]
-  datagrid <- data.frame(object[, grid_names, drop = FALSE])
-
-  if (long || nrow(datagrid) < nrow(results)) {
-    datagrid$Parameter <- unique(results$Parameter)
-    results <- datawizard::data_merge(datagrid, results, by = "Parameter")
-    results$Parameter <- NULL
-    class(results) <- all_class
-  } else {
-    results[grid_names] <- object[grid_names]
-    results$Parameter <- NULL
-    results <- results[, c(grid_names, setdiff(colnames(results), grid_names)), drop = FALSE]
-
-    # add back attributes
-    most_attrs <- all_attrs[setdiff(names(all_attrs), names(attributes(object)))]
-    attributes(results)[names(most_attrs)] <- most_attrs
-  }
-
-  attr(results, "idvars") <- grid_names
-  results
-}
-
 
 #' @keywords internal
 .get_marginaleffects_draws <- function(object) {
   # errors and checks are handled by marginaleffects
-  insight::check_if_installed("marginaleffects", minimum_version = "0.24.0")
-  data.frame(marginaleffects::get_draws(object, shape = "DxP"))
+  insight::check_if_installed("marginaleffects", minimum_version = "0.29.0")
+  as.data.frame(marginaleffects::get_draws(object, shape = "DxP"))
 }
 
+
 #' @keywords internal
 .possibly_extract_rvar_col <- function(df, rvar_col) {
   if (missing(rvar_col) || is.null(rvar_col)) {
