@@ -17,9 +17,13 @@ test_that("bayesfactor_models BIC", {
   BFM3 <- bayesfactor_models(mo2, mo3, mo4, mo1, denominator = mo1)
   BFM4 <<- bayesfactor_models(mo2, mo3, mo4, mo5, mo1, denominator = mo1)
 
-  expect_equal(BFM1, BFM2)
-  expect_equal(BFM1, BFM3)
-  expect_equal(BFM1, bayesfactor_models(list(mo2 = mo2, mo3 = mo3, mo4 = mo4, mo1 = mo1), denominator = 4))
+  expect_equal(BFM1, BFM2, tolerance = 1e-4, ignore_attr = TRUE)
+  expect_equal(BFM1, BFM3, tolerance = 1e-4, ignore_attr = TRUE)
+  expect_equal(
+    BFM1,
+    bayesfactor_models(list(mo2 = mo2, mo3 = mo3, mo4 = mo4, mo1 = mo1), denominator = 4),
+    tolerance = 1e-4, ignore_attr = TRUE
+  )
 
   # only on same data!
   expect_warning(bayesfactor_models(mo1, mo2, mo4_e))
@@ -104,22 +108,20 @@ test_that("bayesfactor_models STAN", {
 
   set.seed(333)
   suppressMessages({
-    expect_warning(
+    expect_warning({
       stan_models <- bayesfactor_models(stan_bf_0, stan_bf_1)
-    )
+    })
   })
   expect_s3_class(stan_models, "bayesfactor_models")
-  expect_equal(length(stan_models$log_BF), 2)
+  expect_length(stan_models$log_BF, 2)
   expect_equal(stan_models$log_BF[2], log(bridge_BF$bf), tolerance = 0.1)
 })
 
 test_that("bayesfactor_models BRMS", {
   # Checks for brms models
   skip_on_cran()
-  skip_on_ci()
+  # skip_on_ci()
 
-  skip_if_not_or_load_if_installed("lme4")
-  skip_if_not_or_load_if_installed("rstanarm")
   skip_if_not_or_load_if_installed("bridgesampling")
   skip_if_not_or_load_if_installed("brms")
 
@@ -143,12 +145,14 @@ test_that("bayesfactor_models BRMS", {
   ))
 
   set.seed(444)
-  suppressMessages(
+  suppressWarnings(suppressMessages(
     expect_message(
-      bfm <- bayesfactor_models(stan_brms_model_0, stan_brms_model_1),
+      {
+        bfm <- bayesfactor_models(stan_brms_model_0, stan_brms_model_1)
+      },
       regexp = "marginal"
     )
-  )
+  ))
 
   set.seed(444)
   stan_brms_model_0wc <- brms::add_criterion(
@@ -165,7 +169,12 @@ test_that("bayesfactor_models BRMS", {
     silent = 2
   )
 
-  expect_message(bfmwc <- bayesfactor_models(stan_brms_model_0wc, stan_brms_model_1wc), regexp = NA)
+  suppressWarnings(expect_message(
+    {
+      bfmwc <- bayesfactor_models(stan_brms_model_0wc, stan_brms_model_1wc)
+    },
+    regexp = NA
+  ))
   expect_equal(bfmwc$log_BF, bfm$log_BF, tolerance = 0.01)
 })
 
@@ -181,7 +190,8 @@ test_that("bayesfactor_inclusion | BayesFactor", {
   BF_ToothGrowth <- BayesFactor::anovaBF(len ~ dose * supp, ToothGrowth)
   expect_equal(
     bayesfactor_inclusion(BF_ToothGrowth),
-    bayesfactor_inclusion(bayesfactor_models(BF_ToothGrowth))
+    bayesfactor_inclusion(bayesfactor_models(BF_ToothGrowth)),
+    tolerance = 1e-4, ignore_attr = TRUE
   )
 })
 
@@ -197,7 +207,7 @@ test_that("bayesfactor_inclusion | LMM", {
   expect_equal(bfinc_all$p_posterior, c(1, 1, 0.12, 0.01, 0), tolerance = 0.1)
   expect_equal(bfinc_all$log_BF, c(NaN, 57.651, -2.352, -4.064, -4.788), tolerance = 0.1)
 
-  # + match_models
+  # plus match_models
   bfinc_matched <- bayesfactor_inclusion(BFM4, match_models = TRUE)
   expect_equal(bfinc_matched$p_prior, c(1, 0.2, 0.6, 0.2, 0.2), tolerance = 0.1)
   expect_equal(bfinc_matched$p_posterior, c(1, 0.875, 0.125, 0.009, 0.002), tolerance = 0.1)
