@@ -54,10 +54,11 @@ test_that("bayesfactor_parameters data frame", {
 
 test_that("bayesfactor_parameters RSTANARM", {
   skip_on_cran()
+  skip_if_not_installed("curl")
   skip_if_offline()
+  skip_if_not_installed("httr2")
   skip_if_not_or_load_if_installed("logspline", "2.1.21")
   skip_if_not_or_load_if_installed("rstanarm")
-  skip_if_not_or_load_if_installed("httr2")
 
   fit <- suppressMessages(stan_glm(mpg ~ ., data = mtcars, refresh = 0))
 
@@ -91,9 +92,10 @@ test_that("bayesfactor_parameters RSTANARM", {
 # bayesfactor_parameters BRMS ---------------------------------------------
 
 test_that("bayesfactor_parameters BRMS", {
+  skip_if_not_installed("curl")
   skip_if_offline()
+  skip_if_not_installed("httr2")
   skip_if_not_or_load_if_installed("logspline", "2.1.21")
-  skip_if_not_or_load_if_installed("httr2")
   skip_if_not_or_load_if_installed("brms")
   skip_if_not_or_load_if_installed("cmdstanr")
   skip_if_not(dir.exists(cmdstanr::cmdstan_default_install_path()))
