@@ -1,11 +1,13 @@
 test_that("brms", {
   skip_on_cran()
+  skip_if_not_installed("curl")
   skip_if_offline()
+  skip_if_not_installed("httr2")
   skip_if_not_or_load_if_installed("brms")
-  skip_if_not_or_load_if_installed("httr2")
 
   set.seed(333)
   model <- insight::download_model("brms_mixed_1")
+  skip_if(is.null(model))
 
   expect_s3_class(hdi(model), "data.frame")
   expect_s3_class(ci(model), "data.frame")
@@ -30,18 +32,20 @@ test_that("brms", {
   ))
   expect_equal(as.vector(s$fixed[, 1, drop = TRUE]), out$Mean[1:2], tolerance = 1e-3)
   expect_equal(as.vector(s$fixed[, 5, drop = TRUE]), out$Rhat[1:2], tolerance = 1e-1)
-  expect_equal(as.vector(s$random$cyl[, 1, drop = TRUE]), out$Mean[12], tolerance = 1e-3)
-  expect_equal(as.vector(s$random$gear[, 1, drop = TRUE]), out$Mean[13:15], tolerance = 1e-3)
+  expect_equal(as.vector(s$random$cyl[, 1, drop = TRUE]), out$Mean[3], tolerance = 1e-3)
+  expect_equal(as.vector(s$random$gear[, 1, drop = TRUE]), out$Mean[4:6], tolerance = 1e-3)
 })
 
 test_that("brms", {
   skip_on_cran()
+  skip_if_not_installed("curl")
   skip_if_offline()
+  skip_if_not_installed("httr2")
   skip_if_not_or_load_if_installed("brms")
-  skip_if_not_or_load_if_installed("httr2")
 
   set.seed(333)
   model <- insight::download_model("brms_1")
+  skip_if(is.null(model))
 
   out <- describe_posterior(model, effects = "all", component = "all", centrality = "mean")
   s <- summary(model)
@@ -55,12 +59,14 @@ test_that("brms", {
 
 test_that("brms", {
   skip_on_cran()
+  skip_if_not_installed("curl")
   skip_if_offline()
+  skip_if_not_installed("httr2")
   skip_if_not_or_load_if_installed("brms")
-  skip_if_not_or_load_if_installed("httr2")
 
   set.seed(333)
   model <- insight::download_model("brms_mv_2")
+  skip_if(is.null(model))
 
   out <- describe_posterior(model, effects = "all", component = "all", centrality = "mean", test = NULL)
   s <- suppressWarnings(summary(model))
@@ -79,12 +85,14 @@ test_that("brms", {
 
 test_that("brms", {
   skip_on_cran()
+  skip_if_not_installed("curl")
   skip_if_offline()
+  skip_if_not_installed("httr2")
   skip_if_not_or_load_if_installed("brms")
-  skip_if_not_or_load_if_installed("httr2")
 
   set.seed(333)
   model <- insight::download_model("brms_2")
+  skip_if(is.null(model))
 
   out <- describe_posterior(model, effects = "all", component = "all", centrality = "mean", test = NULL)
   s <- summary(model)
